@@ -9,6 +9,7 @@
 #include <grp.h>
 #include <sys/time.h>
 #include <fcntl.h>
+#include <sys/file.h>
 #include <alsa/asoundlib.h>
 
 #define VERSION "0.4"
@@ -237,10 +238,13 @@ int main(int argc, char **argv)
 
   snd_mixer_elem_set_callback(elem, elem_callback);
 
-  /* open knob wheel */
+  /* open & lock knob wheel */
   if ((fd = open(device, O_RDWR)) < 0)
     ERR("cannot open %s for reading and writing", device);
 
+  if (flock(fd, LOCK_EX|LOCK_NB) != 0)
+    ERR("cannot lock %s exclusively", device);
+
   if (user) {
     /* drop privileges, chroot */
     if (initgroups(user, pw->pw_gid) < 0) ERR("initgroups()");
